==> com.liferay.commerce.api-22.3.2-sources.jar: com/liferay/commerce/constants/CommerceOrderActionKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.constants;

/**
 * @author Andrea Di Giorgi
 */
public class CommerceOrderActionKeys {

	public static final String ADD_COMMERCE_ORDER = "ADD_COMMERCE_ORDER";

	public static final String APPROVE_COMMERCE_ORDER =
		"APPROVE_COMMERCE_ORDER";

	public static final String APPROVE_OPEN_COMMERCE_ORDERS =
		"APPROVE_OPEN_COMMERCE_ORDERS";

	public static final String CHECKOUT_COMMERCE_ORDER =
		"CHECKOUT_COMMERCE_ORDER";

	public static final String CHECKOUT_OPEN_COMMERCE_ORDERS =
		"CHECKOUT_OPEN_COMMERCE_ORDERS";

	public static final String DELETE_COMMERCE_ORDERS =
		"DELETE_COMMERCE_ORDERS";

	public static final String MANAGE_COMMERCE_ORDER_NOTES =
		"MANAGE_COMMERCE_ORDER_NOTES";

	public static final String MANAGE_COMMERCE_ORDER_RESTRICTED_NOTES =
		"MANAGE_COMMERCE_ORDER_RESTRICTED_NOTES";

	public static final String MANAGE_COMMERCE_ORDERS =
		"MANAGE_COMMERCE_ORDERS";

	public static final String VIEW_COMMERCE_ORDERS = "VIEW_COMMERCE_ORDERS";

	public static final String VIEW_OPEN_COMMERCE_ORDERS =
		"VIEW_OPEN_COMMERCE_ORDERS";

}

==> com.liferay.commerce.api-29.2.0-sources.jar: com/liferay/commerce/constants/CommerceOrderActionKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.constants;

/**
 * @author Andrea Di Giorgi
 */
public class CommerceOrderActionKeys {

	public static final String ADD_COMMERCE_ORDER = "ADD_COMMERCE_ORDER";

	public static final String ADD_COMMERCE_ORDER_TYPE =
		"ADD_COMMERCE_ORDER_TYPE";

	public static final String APPROVE_COMMERCE_ORDER =
		"APPROVE_COMMERCE_ORDER";

	public static final String APPROVE_OPEN_COMMERCE_ORDERS =
		"APPROVE_OPEN_COMMERCE_ORDERS";

	public static final String CHECKOUT_COMMERCE_ORDER =
		"CHECKOUT_COMMERCE_ORDER";

	public static final String CHECKOUT_OPEN_COMMERCE_ORDERS =
		"CHECKOUT_OPEN_COMMERCE_ORDERS";

	public static final String DELETE_COMMERCE_ORDERS =
		"DELETE_COMMERCE_ORDERS";

	public static final String MANAGE_COMMERCE_ORDER_NOTES =
		"MANAGE_COMMERCE_ORDER_NOTES";

	public static final String MANAGE_COMMERCE_ORDER_RESTRICTED_NOTES =
		"MANAGE_COMMERCE_ORDER_RESTRICTED_NOTES";

	public static final String MANAGE_COMMERCE_ORDERS =
		"MANAGE_COMMERCE_ORDERS";

	public static final String VIEW_COMMERCE_ORDER_TYPES =
		"VIEW_COMMERCE_ORDER_TYPES";

	public static final String VIEW_COMMERCE_ORDERS = "VIEW_COMMERCE_ORDERS";

	public static final String VIEW_OPEN_COMMERCE_ORDERS =
		"VIEW_OPEN_COMMERCE_ORDERS";

}
